@@ -26,7 +26,7 @@ from calculate.lib.utils.files import (isMount, readFile, find,
                                        FindFileType)
 from calculate.lib.utils.common import getValueFromCmdLine
 from calculate.lib.utils.portage import isPkgInstalled
-from calculate.lib.variables.user import VariableUrLogin
+from calculate.lib.variables import user
 from calculate.lib.convertenv import convertEnv
 from calculate.lib.utils.ip import isOpenPort
 import time
@@ -271,7 +271,7 @@ class VariableUrUserNewPw(Variable):
             raise VariableError(_("Empty password"))
 
 
-class VariableClClientLogin(VariableUrLogin):
+class VariableClClientLogin(user.VariableUrLogin):
     """
     User Login
     """
@@ -279,7 +279,7 @@ class VariableClClientLogin(VariableUrLogin):
     alias = "ur_login"
 
     def choice(self):
-        loginChoice = VariableUrLogin.choice(self)
+        loginChoice = user.VariableUrLogin.choice(self)
         if self.Get('cl_action') == 'passwd':
             return filter(lambda x: x != "root", loginChoice)
         else:
